function example(ex)

if nargin < 1, ex = 1; end

% Simple examples in box of size 1.
if ex <= 3
  % Defaults
  L = 1;
  D = 0;
  Npts = 200;
  dx = .2;
  switch ex
   case 1

    % example 1: sine map in unit square, small step size, no noise.

    % In this limit the map is a symplective integrator.  The only reason
    % particle orbits are not closed is because T is finite (numerical error
    % in integrator).
    T = .1;

   case 2
    % example 2: sine map in unit square, small step size, with noise.

    % The "near-integrability" is broken.
    T = .1;
    D = 1e-5;

   case 3
    % example 3: sine map in unit square, large step size, no noise.

    % Note the "filaments" that form.  The filaments are as thin as we make
    % the initial blob.
    T = 1;
    dx = .001;
  end
  run_sinemap(T,L,D,Npts,dx)
  return
end

switch ex
 case 4
  % example 4: sine map in unit square, large step size, noise.

  T = 1;
  L = 1;
  Npts = 200;
  dx = .001;

  D = 1e-4;
  fprintf('First map, D = %g\n',D)
  run_sinemap(T,L,D,Npts,dx)

  fprintf('Measure a filament width by clicking twice...\n\n')
  w = ginput(2);
  fprintf('Measured width is %g,',norm(w(1,:)-w(2,:)))
  fprintf(' estimate is %g\n',10*sqrt(D/T))

  D = 1e-6;
  fprintf('Second map, D = %g\n',D)
  run_sinemap(T,L,D,Npts,dx)
  fprintf('Measure a filament width by clicking twice...\n\n')
  w = ginput(2);
  fprintf('Measured width is %g,',norm(w(1,:)-w(2,:)))
  fprintf(' estimate is %g\n',10*sqrt(D/T))
 case 5
  % example 5: sine map in larger domain, moderate step size, noise.

  T = .5;
  L = 1;
  D = 1e-6;
  Npts = 300;
  dx = .1;
  dX2 = run_sinemap(T,L,D,Npts,dx);
  pause

  L = 3;
  dX2 = run_sinemap(T,L,D,Npts,dx);
  pause

  % An even larger-scale view
  % Here the concept of effective diffusivity becomes relevant.
  L = 10;
  dX2 = run_sinemap(T,L,D,Npts,dx);
  pause

  % An even even larger-scale view
  L = 25;
  dX2 = run_sinemap(T,L,D,Npts,dx);
  figure(1), grid off
  a = polyfit([0:length(dX2)-1]',dX2,1);
  Keff = a(1)/4;
  fprintf('\n\neffective diffusivity = %g  (vs %g)\n',Keff,D)
  figure(2), hold on
  plot(0:length(dX2)-1,a(1)*(0:length(dX2)-1),'r--'), hold off
end
