function [varargout] = run_sinemap(T,L,D,Np,sqw)

if nargin < 1, T = 1; end
if nargin < 2, L = 1; end

if nargin < 3
  % Diffusivity (noise)
  D = 0;
end

if nargin < 4
  % Points initial square
  Np = 100;
end
Npx = Np; Npy = Np; Np = Npx*Npy;

if nargin < 5
  % Size of initial square
  sqw = .2;
end

f = @(X) sinemap(X,T/L,1/L);

x = linspace(-sqw/2,sqw/2,Npx)';
y = linspace(-sqw/2,sqw/2,Npy)';
X = [repmat(x,[Npy 1]) kron(y,ones(Npx,1))]/L;

dX2 = mean(sum(mymod(L*X,L).^2,2));
dx2 = mean(mymod(L*X(:,1),L).^2);
dy2 = mean(mymod(L*X(:,2),L).^2);
dxy = mean(mymod(L*X(:,1),L).*mymod(L*X(:,2),L));

it = 0;
figure(1)
plotmap(L*X,T,L,D,it)  % Stretch output.

while 1
  inp = input('Press a key (Q to quit)','s');
  if strcmp(lower(inp),'q'), break; end
  X = f(X); it = it + 1;
  dX2 = [dX2; mean(sum(mymod(L*X,L).^2,2))];
  dx2 = [dx2; mean(mymod(L*X(:,1),L).^2)];
  dy2 = [dy2; mean(mymod(L*X(:,2),L).^2)];
  dxy = [dxy; mean(mymod(L*X(:,1),L).*mymod(L*X(:,2),L))];
  % Add some noise
  if D > 0, X = X + sqrt(2*D)/L*randn(size(X)); end
  figure(1)
  plotmap(L*X,T,L,D,it)  % Stretch output.
end

hold off

if nargout > 0
  varargout{1} = dX2;
  figure(2)
  plot(0:it,dX2,'k.-')
  hold on
  plot(0:it,dx2,'r.--')
  plot(0:it,dy2,'b.--')
  plot(0:it,dxy,'g.--')
  hold off
  xlabel('iteration')
  ylabel('<X^2>')
  legend('<X^2>','<x^2>','<y^2>','<xy>','Location','NorthWest')
end

% ----------------------------------------------------
function Xm = mymod(X,L)

Xm = mod(X + L/2,L) - L/2;

% ----------------------------------------------------
function plotmap(X,T,L,D,it)

plot(mymod(X(:,1),L),mymod(X(:,2),L),'.','MarkerSize',1)
axis([-L/2 L/2 -L/2 L/2])
axis square
title(sprintf('iter = %d,  T = %g   L = %g   D = %g',it,T,L,D))

if L > 1
  gr = (0:L-1) - floor(L/2-.5) - .5;
  set(gca,'XTick',gr)
  set(gca,'YTick',gr)
  set(gca,'XTickLabel',[])
  set(gca,'YTickLabel',[])
  grid on
end
